@@ -18,7 +18,8 @@
 #'   Content Negotiation API service.
 #'   
 #'   DataCite DOIs: Some values of the \code{format} parameter won't work with 
-#'   DataCite DOIs, i.e. "citeproc-json", "crossref-xml", "crossref-tdm", "onix-xml". 
+#'   DataCite DOIs, i.e. "citeproc-json", "crossref-xml", "crossref-tdm", 
+#'     "onix-xml". 
 #'   
 #'   MEDRA DOIs only work with "rdf-xml", "turtle", "citeproc-json-ish", "ris", 
 #'   "bibtex", "bibentry", "onix-xml".
@@ -91,6 +92,11 @@
 #' 
 #' # Get raw output
 #' cr_cn(dois = "10.1002/app.27716", format = "citeproc-json", raw = TRUE)
+#' 
+#' # sometimes messy DOIs even work
+#' ## in this case, a DOI minting agency can't be found
+#' ## but we proceed anyway, just assuming it's "crossref"
+#' cr_cn("10.1890/0012-9615(1999)069[0569:EDILSA]2.0.CO;2")
 #' }
 
 `cr_cn` <- function(dois, format = "bibtex", style = 'apa', 
@@ -102,11 +108,15 @@
                                 "crossref-tdm", "onix-xml"))
 
   cn <- function(doi, ...){
-    agency_id <- GET_agency_id(doi)
-    if (is.na(agency_id)) {
-      stop("no resource location found", doi, message, call. = FALSE)
+    agency_id <- suppressWarnings(GET_agency_id(doi))
+    if (is.null(agency_id)) {
+      warning(doi, " agency not found - proceeding with 'crossref' ...", 
+              call. = FALSE)
+      agency_id <- "crossref"
     }
+    
     url <- paste0("http://data.", agency_id, ".org/", doi)
+    
     # check cn data provider
     if (!format %in% supported_cn_types[[agency_id]]) {
       stop(paste0("Format '", format, "' for '", doi, 
@@ -117,7 +127,8 @@
     pick <- c(
            "rdf-xml" = "application/rdf+xml",
            "turtle" = "text/turtle",
-           "citeproc-json" = "transform/application/vnd.citationstyles.csl+json",
+           "citeproc-json" = 
+             "transform/application/vnd.citationstyles.csl+json",
            "citeproc-json-ish" = "application/vnd.citationstyles.csl+json",
            "text" = "text/x-bibliography",
            "ris" = "application/x-research-info-systems",
@@ -133,7 +144,8 @@
                       make_rcrossref_ua(), ...)
     } else {
       if (format == "text") {
-        type <- paste(type, "; style = ", style, "; locale = ", locale, sep = "")
+        type <- paste(type, "; style = ", style, "; locale = ", locale, 
+                      sep = "")
       }
       response <- GET(url, ..., 
                       make_rcrossref_ua(),
@@ -178,9 +190,13 @@
 
   if (length(dois) > 1) {
     llply(dois, function(z, ...) {
-      out = try(cn(z, ...), silent = TRUE)
+      out <- try(cn(z, ...), silent = TRUE)
       if ("try-error" %in% class(out)) {
-        warning(paste0("Failure in resolving '", z, "'. See error detail in results."))
+        warning(
+          paste0("Failure in resolving '", z, 
+                 "'. See error detail in results."),
+          call. = FALSE
+        )
         out <- list(doi = z, error = out[[1]])
       }
       return(out)
@@ -210,7 +226,14 @@ warn_status <- function(x) {
     } else {
       mssg <- paste(sprintf("(%s)", x$status_code), "-", mssg)
     }
-    warning(sprintf("%s w/ %s", gsub("%2F", "/", httr::parse_url(x$url)$path), mssg))
+    warning(
+      sprintf(
+        "%s w/ %s", 
+        gsub("%2F", "/", httr::parse_url(x$url)$path), 
+        mssg
+      ),
+      call. = FALSE
+    )
   }
 }
 
@@ -228,9 +251,11 @@ GET_agency_id <- function(x, ...) {
 # Supported content types
 # See http://www.crosscite.org/cn/
 supported_cn_types <- list(
-  crossref = c("rdf-xml", "turtle", "citeproc-json", "citeproc-json-ish", "text", "ris", "bibtex", 
-               "crossref-xml", "bibentry", "crossref-tdm"),
-  datacite = c("rdf-xml", "turtle", "datacite-xml", "citeproc-json-ish", "text", "ris", "bibtex", 
-               "bibentry"),
-  medra = c("rdf-xml", "turtle", "citeproc-json-ish", "ris", "bibtex", "bibentry", "onix-xml")
+  crossref = c("rdf-xml", "turtle", "citeproc-json", "citeproc-json-ish", 
+               "text", "ris", "bibtex", "crossref-xml", "bibentry", 
+               "crossref-tdm"),
+  datacite = c("rdf-xml", "turtle", "datacite-xml", "citeproc-json-ish", "text",
+               "ris", "bibtex", "bibentry"),
+  medra = c("rdf-xml", "turtle", "citeproc-json-ish", "ris", "bibtex", 
+            "bibentry", "onix-xml")
 )
