@@ -15,28 +15,34 @@
 #'
 #' Note that some parameters are ignored unless \code{works=TRUE}: sample, sort,
 #' order, filter
-#' @references \url{https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md}
+#' @references 
+#' \url{https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md}
 #' @examples \dontrun{
 #' cr_journals(issn="2167-8359")
 #' cr_journals()
 #' cr_journals(issn="2167-8359", works=TRUE)
 #' cr_journals(issn=c('1803-2427','2326-4225'))
 #' cr_journals(query="ecology")
-#' cr_journals(issn="2167-8359", query='ecology', works=TRUE, sort='score', order="asc")
-#' cr_journals(issn="2167-8359", query='ecology', works=TRUE, sort='score', order="desc")
-#' cr_journals(issn="2167-8359", works=TRUE, filter=c(from_pub_date='2014-03-03'))
+#' cr_journals(issn="2167-8359", query='ecology', works=TRUE, 
+#'    sort='score', order="asc")
+#' cr_journals(issn="2167-8359", query='ecology', works=TRUE, sort='score', 
+#'    order="desc")
+#' cr_journals(issn="2167-8359", works=TRUE, 
+#'    filter=c(from_pub_date='2014-03-03'))
 #' cr_journals(query="peerj")
 #' cr_journals(issn='1803-2427', works=TRUE)
 #' cr_journals(issn='1803-2427', works=TRUE, sample=1)
 #' cr_journals(limit=2)
 #'
 #' # Use the cursor for deep paging
-#' cr_journals(issn='1932-6203', works = TRUE, cursor = "*", cursor_max = 500, limit = 100)
+#' cr_journals(issn='1932-6203', works = TRUE, cursor = "*", cursor_max = 500, 
+#'    limit = 100)
 #' cr_journals(c('1932-6203', '0028-0836'), works = TRUE, cursor = "*",
 #'    cursor_max = 300, limit = 100)
 #'
 #' # fails, if you want works, you must give an ISSN
-#' # cr_journals(query = "ecology", filter=c(has_full_text = TRUE), works = TRUE)
+#' # cr_journals(query = "ecology", filter=c(has_full_text = TRUE), 
+#' #    works = TRUE)
 #'
 #' # Low level function - does no parsing to data.frame, get json or a list
 #' cr_journals_(query = 'ecology')
@@ -52,12 +58,18 @@
   limit = NULL, sample = NULL, sort = NULL, order = NULL, facet = FALSE, works=FALSE,
   cursor = NULL, cursor_max = 5000, .progress="none", ...) {
 
-  if (works) if (is.null(issn)) stop("If `works=TRUE`, you must give a journal ISSN", call. = FALSE)
-  args <- prep_args(query, filter, offset, limit, sample, sort, order, facet, cursor)
+  if (works) {
+    if (is.null(issn)) {
+      stop("If `works=TRUE`, you must give a journal ISSN", call. = FALSE)
+    }
+  }
+  args <- prep_args(query, filter, offset, limit, sample, 
+                    sort, order, facet, cursor)
 
   if (length(issn) > 1) {
     res <- llply(issn, journal_GET, args = args, works = works,
-                 cursor = cursor, cursor_max = cursor_max, ..., .progress = .progress)
+                 cursor = cursor, cursor_max = cursor_max, ..., 
+                 .progress = .progress)
     if (!is.null(cursor)) {
       out <- lapply(res, "[[", "data")
       tbl_df(bind_rows(out))
@@ -67,7 +79,8 @@
       res <- cr_compact(res)
       res <- lapply(res, parse_works)
       df <- tbl_df(bind_rows(res))
-      #exclude rows with empty ISSN value until CrossRef API supports input validation
+      #exclude rows with empty ISSN value until CrossRef API 
+      #supports input validation
       if (nrow(df[df$ISSN == "", ]) > 0) {
         warning("only data with valid ISSN returned",  call. = FALSE)
       }
@@ -90,7 +103,10 @@
       } else {
         fxn <- if (works) parse_works else parse_journal
         meta <- parse_meta(tmp)
-        list(meta = meta, data = tbl_df(bind_rows(lapply(tmp$message$items, fxn))))
+        list(
+          meta = meta, 
+          data = tbl_df(bind_rows(lapply(tmp$message$items, fxn)))
+        )
       }
     }
   }
@@ -98,12 +114,18 @@
 
 #' @export
 #' @rdname cr_journals
-`cr_journals_` <- function(issn = NULL, query = NULL, filter = NULL, offset = NULL,
-  limit = NULL, sample = NULL, sort = NULL, order = NULL, facet = FALSE, works=FALSE,
-  cursor = NULL, cursor_max = 5000, .progress="none", parse=FALSE, ...) {
+`cr_journals_` <- function(issn = NULL, query = NULL, filter = NULL, 
+  offset = NULL, limit = NULL, sample = NULL, sort = NULL, order = NULL, 
+  facet = FALSE, works=FALSE, cursor = NULL, cursor_max = 5000, 
+  .progress="none", parse=FALSE, ...) {
 
-  if (works) if (is.null(issn)) stop("If `works=TRUE`, you must give a journal ISSN", call. = FALSE)
-  args <- prep_args(query, filter, offset, limit, sample, sort, order, facet, cursor)
+  if (works) {
+    if (is.null(issn)) {
+      stop("If `works=TRUE`, you must give a journal ISSN", call. = FALSE)
+    }
+  }
+  args <- prep_args(query, filter, offset, limit, sample, sort, order, 
+                    facet, cursor)
   if (length(issn) > 1) {
     llply(issn, journal_GET_, args = args, works = works,
           cursor = cursor, cursor_max = cursor_max,
@@ -130,7 +152,8 @@ journal_GET <- function(x, args, works, cursor = NULL, cursor_max = NULL, ...){
   }
 }
 
-journal_GET_ <- function(x, args, works, cursor = NULL, cursor_max = NULL, parse, ...){
+journal_GET_ <- function(x, args, works, cursor = NULL, cursor_max = NULL, 
+                         parse, ...){
   path <- if (!is.null(x)) {
     if (works) sprintf("journals/%s/works", x) else sprintf("journals/%s", x)
   } else {
@@ -147,11 +170,24 @@ journal_GET_ <- function(x, args, works, cursor = NULL, cursor_max = NULL, parse
   }
 }
 
-parse_journal <- function(x){
-  if (!is.null(x$flags)) names(x$flags) <- names2underscore(names(x$flags)) else x$flags <- NA
-  if (!is.null(x$coverage)) names(x$coverage) <- names2underscore(names(x$coverage)) else x$coverage <- NA
-  if (!is.null(x$counts)) names(x$counts) <- names2underscore(names(x$counts)) else x$counts <- NA
-  data.frame(title = x$title, publisher = x$publisher, issn = paste_longer(x$ISSN[[1]]),
+parse_journal <- function(x) {
+  if (!is.null(x$flags)) {
+    names(x$flags) <- names2underscore(names(x$flags)) 
+  } else {
+    x$flags <- NA
+  }
+  if (!is.null(x$coverage)) {
+    names(x$coverage) <- names2underscore(names(x$coverage)) 
+  } else {
+    x$coverage <- NA
+  }
+  if (!is.null(x$counts)) {
+    names(x$counts) <- names2underscore(names(x$counts)) 
+  } else {
+    x$counts <- NA
+  }
+  issn <- if (length(x$ISSN) == 0) NULL else x$ISSN[[1]]
+  data.frame(title = x$title, publisher = x$publisher, issn = paste_longer(issn),
              last_status_check_time = convtime(x$`last-status-check-time`),
              x$flags,
              x$coverage,
@@ -164,4 +200,6 @@ paste_longer <- function(w) {
   if (is.null(w)) NA else w
 }
 
-names2underscore <- function(w) t(sapply(w, function(z) gsub("-", "_", z), USE.NAMES = FALSE))
+names2underscore <- function(w) {
+  t(sapply(w, function(z) gsub("-", "_", z), USE.NAMES = FALSE))
+}
