@@ -2,7 +2,8 @@
 #'
 #' @export
 #'
-#' @param prefixes (character) Publisher prefixes, one or more in a vector or list. Required.
+#' @param prefixes (character) Publisher prefixes, one or more in a vector or 
+#' list. Required.
 #' @template args
 #' @template moreargs
 #' @template cursor_args
@@ -13,21 +14,25 @@
 #'
 #' @details BEWARE: The API will only work for CrossRef DOIs.
 #'
-#' Note that any one publisher can have more than one DOI. If you want to search on
-#' all DOIs for a publisher, pass in all DOIs, or see \code{\link{cr_members}}, and pass in the
-#' \code{member_ids} parameter.
+#' Note that any one publisher can have more than one DOI. If you want to 
+#' search on all DOIs for a publisher, pass in all DOIs, or see 
+#' \code{\link{cr_members}}, and pass in the \code{member_ids} parameter.
 #'
 #' Notes from CrossRef (quoting them):
 #'
-#' The prefix of a CrossRef DOI does NOT indicate who currently owns the DOI. It only
-#' reflects who originally registered the DOI. CrossRef metadata has an \code{owner_prefix}
-#' element that records the current owner of the CrossRef DOI in question.
+#' The prefix of a CrossRef DOI does NOT indicate who currently owns the DOI. 
+#' It only reflects who originally registered the DOI. CrossRef metadata has 
+#' an \code{owner_prefix} element that records the current owner of the 
+#' CrossRef DOI in question.
 #'
-#' CrossRef also has member IDs for depositing organisations. A single member may control multiple
-#' owner prefixes, which in turn may control a number of DOIs. When looking at works published by
-#' a certain organisaton, member IDs and the member routes should be used.
+#' CrossRef also has member IDs for depositing organisations. A single member 
+#' may control multiple owner prefixes, which in turn may control a number of 
+#' DOIs. When looking at works published by a certain organisaton, member 
+#' IDs and the member routes should be used.
 #'
-#' @references \url{https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md}
+#' @references 
+#' \url{https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md}
+#' 
 #' @examples \dontrun{
 #' cr_prefixes(prefixes="10.1016")
 #' cr_prefixes(prefixes="10.1016", works=TRUE)
@@ -45,7 +50,8 @@
 #' cr_prefixes(prefixes=c('10.1016','10.1371'), works=TRUE, facet=TRUE)
 #'
 #' # Use the cursor for deep paging
-#' cr_prefixes("10.1016", works = TRUE, cursor = "*", cursor_max = 500, limit = 100)
+#' cr_prefixes("10.1016", works = TRUE, cursor = "*", cursor_max = 500, 
+#'    limit = 100)
 #' cr_prefixes(c('10.1016', '10.1371'), works = TRUE, cursor = "*",
 #'    cursor_max = 300, limit = 100)
 #'
@@ -53,7 +59,8 @@
 #' cr_prefixes_("10.1016")
 #' cr_prefixes_(c('10.1016', '10.1371'))
 #' cr_prefixes_("10.1016", works = TRUE, query = 'ecology', limit = 10)
-#' cr_prefixes_("10.1016", works = TRUE, query = 'ecology', parse=TRUE, limit = 10)
+#' cr_prefixes_("10.1016", works = TRUE, query = 'ecology', parse=TRUE, 
+#'    limit = 10)
 #' cr_prefixes_("10.1016", works = TRUE, cursor = "*",
 #'    cursor_max = 300, limit = 100)
 #' cr_prefixes_("10.1016", works = TRUE, cursor = "*",
@@ -61,21 +68,32 @@
 #' }
 
 `cr_prefixes` <- function(prefixes, query = NULL, filter = NULL, offset = NULL,
-  limit = NULL, sample = NULL, sort = NULL, order = NULL, facet=FALSE, works = FALSE,
-  cursor = NULL, cursor_max = 5000, .progress="none", ...) {
+  limit = NULL, sample = NULL, sort = NULL, order = NULL, facet=FALSE, 
+  works = FALSE, cursor = NULL, cursor_max = 5000, .progress="none", ...) {
 
-  args <- prep_args(query, filter, offset, limit, sample, sort, order, facet, cursor)
+  args <- prep_args(query, filter, offset, limit, sample, sort, order, 
+                    facet, cursor)
   if (length(prefixes) > 1) {
     res <- llply(prefixes, prefixes_GET, args = args, works = works,
-                 cursor = cursor, cursor_max = cursor_max, ..., .progress = .progress)
+                 cursor = cursor, cursor_max = cursor_max, ..., 
+                 .progress = .progress)
     if (!is.null(cursor)) {
       out <- lapply(res, "[[", "data")
       bind_rows(out)
     } else {
       out <- lapply(res, "[[", "message")
-      out <- if (works) do.call(c, lapply(out, function(x) lapply(x$items, parse_works))) else lapply(out, DataFrame)
+      out <- if (works) {
+        do.call(c, lapply(out, function(x) lapply(x$items, parse_works))) 
+      } else {
+        lapply(out, DataFrame)
+      }
       df <- bind_rows(out)
-      meta <- if (works) data.frame(prefix = prefixes, do.call(rbind, lapply(res, parse_meta)), stringsAsFactors = FALSE) else NULL
+      meta <- if (works) {
+        data.frame(prefix = prefixes, do.call(rbind, lapply(res, parse_meta)), 
+                   stringsAsFactors = FALSE) 
+      } else {
+        NULL
+      }
       if (facet) {
         ft <- Map(function(x, y) {
           rr <- list(parse_facets(x$message$facets)); names(rr) <- y; rr
@@ -86,12 +104,21 @@
       list(meta = meta, data = df, facets = ft)
     }
   } else {
-    tmp <- prefixes_GET(prefixes, args, works = works, cursor = cursor, cursor_max = cursor_max, ...)
+    tmp <- prefixes_GET(prefixes, args, works = works, cursor = cursor, 
+                        cursor_max = cursor_max, ...)
     if (!is.null(cursor)) {
       tmp
     } else {
-      out <- if (works) bind_rows(lapply(tmp$message$items, parse_works)) else DataFrame(tmp$message)
-      meta <- if (works) data.frame(prefix = prefixes, parse_meta(tmp), stringsAsFactors = FALSE) else NULL
+      out <- if (works) {
+        bind_rows(lapply(tmp$message$items, parse_works)) 
+      } else {
+        DataFrame(tmp$message)
+      }
+      meta <- if (works) {
+        data.frame(prefix = prefixes, parse_meta(tmp), stringsAsFactors = FALSE) 
+      } else {
+        NULL
+      }
       list(meta = meta, data = out, facets = parse_facets(tmp$message$facets))
     }
   }
@@ -103,7 +130,8 @@
   limit = NULL, sample = NULL, sort = NULL, order = NULL, facet=FALSE, works = FALSE,
   cursor = NULL, cursor_max = 5000, .progress="none", parse=FALSE, ...) {
 
-  args <- prep_args(query, filter, offset, limit, sample, sort, order, facet, cursor)
+  args <- prep_args(query, filter, offset, limit, sample, sort, order, 
+                    facet, cursor)
   if (length(prefixes) > 1) {
     llply(prefixes, prefixes_GET_, args = args, works = works,
           cursor = cursor, cursor_max = cursor_max, parse = parse,
