@@ -3,16 +3,16 @@ context("testing cr_search_free")
 
 test_that("cr_search_free returns", {
   skip_on_cran()
-  
-  a <- cr_search_free(query = "Piwowar Sharing Detailed Research Data Is Associated with Increased Citation Rate PLOS one 2007")
-  b <- cr_search_free(query="Renear 2012")
-  c <- doi <- cr_search_free(query="Piwowar sharing data PLOS one")$doi
-  d <- cr_search(doi = doi)
+
+  a <- suppressWarnings(cr_search_free(query = "Piwowar Sharing Detailed Research Data Is Associated with Increased Citation Rate PLOS one 2007"))
+  b <- suppressWarnings(cr_search_free(query="Renear 2012"))
+  c <- doi <- suppressWarnings(cr_search_free(query="Piwowar sharing data PLOS one"))$doi
+  d <- suppressWarnings(cr_search(doi = doi))
   queries <- c("Piwowar sharing data PLOS one", "Priem Scientometrics 2.0 social web",
-               "William Gunn A Crosstalk Between Myeloma Cells", 
+               "William Gunn A Crosstalk Between Myeloma Cells",
                "karthik ram Metapopulation dynamics override local limits")
-  e <- cr_search_free(queries)
-  
+  e <- suppressWarnings(cr_search_free(queries))
+
   #  correct class
   expect_is(a, "data.frame")
   expect_is(b, "data.frame")
@@ -33,8 +33,8 @@ test_that("cr_search_free returns", {
 
 test_that("cr_search_free fails correctly", {
   skip_on_cran()
-  
+
   library('httr')
-  expect_error(cr_search_free(config=timeout(0.01)))
-  expect_match(cr_search_free("Asdfadf")$reason, "Too few terms")
+  expect_error(suppressWarnings(cr_search_free(config=timeout(0.01))))
+  expect_match(suppressWarnings(cr_search_free("Asdfadf"))$reason, "Too few terms")
 })
